@@ -51,6 +51,11 @@ class StatefulUser(User):
     state: UserState
 
 
+@dataclass(kw_only=True)
+class StatefulUserWithId(StatefulUser):
+    ext_id: str
+
+
 @dataclass
 class CameraGroup:
     name: str
@@ -133,10 +138,10 @@ class NetrisGatewayConnector:
             "/user/get", {"id": id}, headers=self._construct_bearer_auth_header(token))
         return dict_to_dataclass(answer, StatefulUser)
 
-    async def get_user_by_login(self, token: str, login: str) -> StatefulUser | None:
+    async def get_user_by_login(self, token: str, login: str) -> StatefulUserWithId | None:
         answer = await self._connector.post(
             "/user/get_by_login", {"login": login}, headers=self._construct_bearer_auth_header(token))
-        return dict_to_dataclass(answer, StatefulUser)
+        return dict_to_dataclass(answer, StatefulUserWithId)
 
     async def block_user(self, token: str, id: str) -> bool:
         answer = await self._connector.post(
